akismet
=======

``akismet`` is a Python library wrapping `the Wordpress Akismet spam-filtering
service <https://akismet.com/>`_. All methods of the Akismet API are supported:

* Checking comments for spam

* Reporting comments incorrectly classified as not spam

* Reporting comments incorrectly classified as spam

Use of this module requires an Akismet API key (which must be obtained
from the Akismet service).


Documentation contents
----------------------

.. toctree::
   :maxdepth: 1

   install
   overview
   upgrade
   faq